@@ -4,8 +4,8 @@
 
 ;; Author: Jonathan Chu <me@jonathanchu.is>
 ;; URL: https://github.com/jonathanchu/magit-gh
-;; Package-Version: 20260217.442
-;; Package-Revision: ef7714bf287f
+;; Package-Version: 20260221.522
+;; Package-Revision: 5b3cb8f367e3
 ;; Package-Requires: ((emacs "29.1") (magit "4.0.0") (transient "0.5.0"))
 ;; Keywords: git tools vc github
 
@@ -97,9 +97,11 @@ Set this variable before loading the package to use a custom key."
    ("s" "PR status dashboard" magit-gh-pr-status)]
   ["Inspect"
    ("d" "Diff PR" magit-gh-pr-diff)
-   ("k" "PR checks/CI status" magit-gh-pr-checks)]
+   ("k" "PR checks/CI status" magit-gh-pr-checks)
+   ("a" "Actions (workflow runs)" magit-gh-actions)]
   ["Actions"
    ("c" "Checkout PR" magit-gh-pr-checkout)
+   ("w" "Create PR (web)" magit-gh-pr-create)
    ("v" "View PR in browser" magit-gh-pr-view)])
 
 ;;; PR List Buffer Mode
@@ -119,6 +121,8 @@ One of \"open\", \"closed\", \"merged\", or \"all\".")
     (define-key map (kbd "d") #'magit-gh-pr-list-diff)
     (define-key map (kbd "v") #'magit-gh-pr-list-browse)
     (define-key map (kbd "k") #'magit-gh-pr-list-checks)
+    (define-key map (kbd "n") #'magit-gh--next-item)
+    (define-key map (kbd "p") #'magit-gh--previous-item)
     (define-key map (kbd "t") #'magit-gh-pr-list-cycle-state)
     (define-key map (kbd "g") #'magit-gh-pr-list-refresh)
     map)
@@ -183,6 +187,38 @@ One of \"open\", \"closed\", \"merged\", or \"all\".")
   "Face for age and merged columns in the PR list."
   :group 'magit-gh)
 
+;;; Navigation
+
+(defun magit-gh--next-item ()
+  "Move point to the next item row."
+  (interactive)
+  (let ((start (point))
+        (prop (cond
+               ((derived-mode-p 'magit-gh-pr-checks-mode) 'magit-gh-check-link)
+               ((derived-mode-p 'magit-gh-actions-mode) 'magit-gh-run-url)
+               (t 'magit-gh-pr-number))))
+    (forward-line 1)
+    (while (and (not (eobp))
+                (not (get-text-property (line-beginning-position) prop)))
+      (forward-line 1))
+    (unless (get-text-property (line-beginning-position) prop)
+      (goto-char start))))
+
+(defun magit-gh--previous-item ()
+  "Move point to the previous item row."
+  (interactive)
+  (let ((start (point))
+        (prop (cond
+               ((derived-mode-p 'magit-gh-pr-checks-mode) 'magit-gh-check-link)
+               ((derived-mode-p 'magit-gh-actions-mode) 'magit-gh-run-url)
+               (t 'magit-gh-pr-number))))
+    (forward-line -1)
+    (while (and (not (bobp))
+                (not (get-text-property (line-beginning-position) prop)))
+      (forward-line -1))
+    (unless (get-text-property (line-beginning-position) prop)
+      (goto-char start))))
+
 ;;; Helper functions
 
 (defun magit-gh--repo-dir ()
@@ -331,6 +367,16 @@ Returns \"\" for nil input."
        ((< days 365) (format "%dmo" (floor (/ days 30))))
        (t (format "%dy" (floor (/ days 365))))))))
 
+(defun magit-gh--default-branch ()
+  "Return the default branch name of the current GitHub repository."
+  (let* ((default-directory (magit-gh--repo-dir))
+         (output (string-trim
+                  (shell-command-to-string
+                   "gh repo view --json defaultBranchRef --jq '.defaultBranchRef.name'"))))
+    (if (string-empty-p output)
+        "main"
+      output)))
+
 (defun magit-gh--pr-choices (prs)
   "Build an alist of display strings to PR numbers from PRS."
   (mapcar (lambda (pr)
@@ -421,7 +467,7 @@ When SHOW-MERGED-COL is non-nil, append the merged age at end of row."
 (defun magit-gh-pr-list--update-header-line ()
   "Update the header line to reflect the current state filter."
   (setq-local header-line-format
-              " c:checkout  d:diff  v:browse  k:checks  t:toggle state  g:refresh  q:quit"))
+              " n/p:navigate  c:checkout  d:diff  v:browse  k:checks  t:toggle state  g:refresh  q:quit"))
 
 (defun magit-gh-pr-list--state-indicator (active-state)
   "Return a propertized state indicator string for ACTIVE-STATE.
@@ -494,6 +540,8 @@ Highlights the active state and dims the others."
     (define-key map (kbd "d") #'magit-gh-pr-status-diff)
     (define-key map (kbd "v") #'magit-gh-pr-status-browse)
     (define-key map (kbd "k") #'magit-gh-pr-status-checks)
+    (define-key map (kbd "n") #'magit-gh--next-item)
+    (define-key map (kbd "p") #'magit-gh--previous-item)
     (define-key map (kbd "g") #'magit-gh-pr-status-refresh)
     map)
   "Keymap for `magit-gh-pr-status-mode'.")
@@ -510,7 +558,8 @@ Highlights the active state and dims the others."
   (setq-local header-line-format
               (substitute-command-keys
                "\\<magit-gh-pr-status-mode-map>\
- \\[magit-gh-pr-status-checkout]:checkout  \
+ \\[magit-gh--next-item]/\\[magit-gh--previous-item]:navigate  \
+\\[magit-gh-pr-status-checkout]:checkout  \
 \\[magit-gh-pr-status-diff]:diff  \
 \\[magit-gh-pr-status-browse]:browse  \
 \\[magit-gh-pr-status-checks]:checks  \
@@ -702,6 +751,33 @@ and your recently merged PRs."
       (let ((default-directory (magit-gh--repo-dir)))
         (shell-command (format "gh pr view %d --web" number))))))
 
+(defun magit-gh-pr-create ()
+  "Create a pull request for the current branch, finishing on the web.
+Prompts for the base branch with the repository default pre-filled,
+then opens the GitHub PR creation page in the browser."
+  (interactive)
+  (magit-gh--check-gh)
+  (let* ((default-directory (magit-gh--repo-dir))
+         (current-branch (magit-get-current-branch))
+         (default-base (magit-gh--default-branch)))
+    (unless current-branch
+      (user-error "Not on any branch (detached HEAD)"))
+    (let ((base (completing-read
+                 (format "Create PR: %s → " current-branch)
+                 (magit-list-branch-names)
+                 nil nil default-base)))
+      (when (equal current-branch base)
+        (user-error "Head and base branch cannot be the same"))
+      (message "Opening PR creation for %s → %s..." current-branch base)
+      (let ((exit-code (call-process-shell-command
+                        (format "gh pr create --base %s --web"
+                                (shell-quote-argument base))
+                        nil "*magit-gh-output*" nil)))
+        (if (= exit-code 0)
+            (message "PR creation opened in browser for %s → %s"
+                     current-branch base)
+          (user-error "Failed to create PR; see *magit-gh-output* buffer"))))))
+
 ;;; PR Checks Buffer Mode
 
 (defvar-local magit-gh-pr-checks--repo-dir nil
@@ -714,6 +790,8 @@ and your recently merged PRs."
   (let ((map (make-sparse-keymap)))
     (set-keymap-parent map special-mode-map)
     (define-key map (kbd "v") #'magit-gh-pr-checks-browse)
+    (define-key map (kbd "n") #'magit-gh--next-item)
+    (define-key map (kbd "p") #'magit-gh--previous-item)
     (define-key map (kbd "g") #'magit-gh-pr-checks-refresh)
     map)
   "Keymap for `magit-gh-pr-checks-mode'.")
@@ -726,7 +804,7 @@ and your recently merged PRs."
 \\[magit-gh-pr-checks-refresh] - Refresh the checks
 \\[quit-window] - Close the buffer"
   :group 'magit-gh
-  (setq-local header-line-format " v:browse  g:refresh  q:quit")
+  (setq-local header-line-format " n/p:navigate  v:browse  g:refresh  q:quit")
   (hl-line-mode 1))
 
 ;;; PR Checks Helper Functions
@@ -924,6 +1002,149 @@ If NUMBER is nil, show checks for the current branch's PR."
   (let ((default-directory magit-gh-pr-checks--repo-dir))
     (magit-gh--show-pr-checks magit-gh-pr-checks--pr-number)))
 
+;;; Actions (Workflow Runs) Buffer Mode
+
+(defvar-local magit-gh-actions--repo-dir nil
+  "The repository directory for the current actions buffer.")
+
+(defvar magit-gh-actions-mode-map
+  (let ((map (make-sparse-keymap)))
+    (set-keymap-parent map special-mode-map)
+    (define-key map (kbd "v") #'magit-gh-actions-browse)
+    (define-key map (kbd "n") #'magit-gh--next-item)
+    (define-key map (kbd "p") #'magit-gh--previous-item)
+    (define-key map (kbd "g") #'magit-gh-actions-refresh)
+    map)
+  "Keymap for `magit-gh-actions-mode'.")
+
+(define-derived-mode magit-gh-actions-mode special-mode "GH-Actions"
+  "Major mode for viewing GitHub Actions workflow runs.
+
+\\<magit-gh-actions-mode-map>\
+\\[magit-gh-actions-browse] - Open the run at point in browser
+\\[magit-gh-actions-refresh] - Refresh the workflow runs
+\\[quit-window] - Close the buffer"
+  :group 'magit-gh
+  (setq-local header-line-format " n/p:navigate  v:browse  g:refresh  q:quit")
+  (hl-line-mode 1))
+
+;;; Actions Helper Functions
+
+(defun magit-gh--run-status-display (status conclusion)
+  "Return a propertized string for workflow run STATUS and CONCLUSION."
+  (if (equal status "completed")
+      (pcase conclusion
+        ("success"
+         (propertize "success" 'face 'magit-gh-pr-review-approved))
+        ((or "failure" "cancelled")
+         (propertize conclusion 'face 'magit-gh-pr-review-changes-requested))
+        ("skipped"
+         (propertize "skipped" 'face 'magit-gh-pr-author))
+        (_
+         (propertize (or conclusion "—") 'face 'magit-gh-pr-author)))
+    (propertize (or status "—") 'face 'magit-gh-pr-review-pending)))
+
+(defun magit-gh--run-url-at-point ()
+  "Get the workflow run URL from the text property at point."
+  (get-text-property (line-beginning-position) 'magit-gh-run-url))
+
+;;; Actions Rendering
+
+(defun magit-gh-actions--insert-row (run)
+  "Insert a single row for workflow RUN alist into the current buffer."
+  (let* ((status (or (alist-get 'status run) ""))
+         (conclusion (alist-get 'conclusion run))
+         (name (or (alist-get 'name run) ""))
+         (branch (or (alist-get 'headBranch run) ""))
+         (event (or (alist-get 'event run) ""))
+         (created-at (alist-get 'createdAt run))
+         (age (magit-gh--format-age created-at))
+         (url (or (alist-get 'url run) ""))
+         (status-display (magit-gh--run-status-display status conclusion))
+         (name-display (if (> (length name) 30)
+                           (concat (substring name 0 27) "...")
+                         name))
+         (branch-display (if (> (length branch) 25)
+                             (concat (substring branch 0 22) "...")
+                           branch))
+         (start (point)))
+    (insert (format "%-14s " status-display)
+            (propertize (format "%-32s " name-display)
+                        'face 'magit-gh-pr-title)
+            (propertize (format "%-27s " branch-display)
+                        'face 'magit-gh-pr-branch)
+            (propertize (format "%-16s " event)
+                        'face 'magit-gh-pr-author)
+            (propertize age 'face 'magit-gh-pr-age)
+            "\n")
+    (put-text-property start (point) 'magit-gh-run-url url)))
+
+(defun magit-gh-actions--render (buf data)
+  "Insert workflow run DATA into BUF."
+  (when (buffer-live-p buf)
+    (with-current-buffer buf
+      (let ((inhibit-read-only t))
+        (erase-buffer)
+        (insert (propertize "Actions" 'face 'magit-gh-header) "\n\n")
+        (if (null data)
+            (insert (propertize "No workflow runs found."
+                                'face 'magit-gh-pr-author))
+          (insert (propertize (format "%-14s %-32s %-27s %-16s %s"
+                                      "Status" "Workflow" "Branch"
+                                      "Event" "Age")
+                              'face 'magit-gh-header)
+                  "\n")
+          (insert (propertize (make-string 96 ?─) 'face 'magit-gh-header)
+                  "\n")
+          (dolist (run data)
+            (magit-gh-actions--insert-row run)))
+        (goto-char (point-min))
+        (when data (forward-line 4))))))
+
+;;; Actions Commands
+
+(defun magit-gh-actions ()
+  "Show GitHub Actions for the current repository."
+  (interactive)
+  (magit-gh--check-gh)
+  (let* ((repo-dir (magit-gh--repo-dir))
+         (default-directory repo-dir)
+         (cmd "gh run list --json status,conclusion,name,headBranch,event,createdAt,url --limit 20")
+         (buf (get-buffer-create "*magit-gh: Actions*")))
+    (with-current-buffer buf
+      (let ((inhibit-read-only t))
+        (erase-buffer)
+        (insert (propertize "Loading..." 'face 'magit-gh-pr-author)))
+      (magit-gh-actions-mode)
+      (setq magit-gh-actions--repo-dir repo-dir))
+    (pop-to-buffer buf)
+    (magit-gh--async-fetch
+     cmd
+     (lambda (data)
+       (magit-gh-actions--render buf data))
+     (lambda (msg)
+       (when (buffer-live-p buf)
+         (with-current-buffer buf
+           (let ((inhibit-read-only t))
+             (erase-buffer)
+             (insert (propertize msg
+                                'face 'magit-gh-pr-review-changes-requested)))))))))
+
+(defun magit-gh-actions-browse ()
+  "Open the workflow run at point in the browser."
+  (interactive)
+  (if-let ((url (magit-gh--run-url-at-point)))
+      (if (string-empty-p url)
+          (user-error "No URL for run at point")
+        (browse-url url))
+    (user-error "No run at point")))
+
+(defun magit-gh-actions-refresh ()
+  "Refresh the actions buffer."
+  (interactive)
+  (let ((default-directory magit-gh-actions--repo-dir))
+    (magit-gh-actions)))
+
 ;;; Integration with Magit
 
 (transient-append-suffix 'magit-dispatch "!"
